@@ -5,12 +5,14 @@
 #'              random graph modeling (ERGM) framework with extensions for
 #'              dynamic/temporal models (STERGM).
 #'
-#' @param nw An object of class \code{network}.
+#' @param nw An object of class \code{network} or \code{egor}, with the latter
+#'        indicating an \code{ergm.ego} fit.
 #' @param formation Right-hand sided STERGM formation formula in the form
 #'        \code{~edges + ...}, where \code{...} are additional network
 #'        statistics.
 #' @param target.stats Vector of target statistics for the formation model, with
-#'        one number for each network statistic in the model.
+#'        one number for each network statistic in the model.  Ignored if
+#'        fitting via \code{ergm.ego}.
 #' @param coef.diss An object of class \code{disscoef} output from the
 #'        \code{\link{dissolution_coefs}} function.
 #' @param constraints Right-hand sided formula specifying constraints for the
@@ -20,9 +22,13 @@
 #'        formula.
 #' @param edapprox If \code{TRUE}, use the indirect edges dissolution
 #'        approximation  method for the dynamic model fit, otherwise use the
-#'        more time-intensive full STERGM estimation (see details).
+#'        more time-intensive full STERGM estimation (see details).  For
+#'        \code{nw} of class \code{egor}, only \code{edapprox = TRUE} is
+#'        supported.
 #' @param set.control.ergm Control arguments passed to \code{ergm} (see
 #'        details).
+#' @param set.control.ergm.ego Control arguments passed to \code{ergm.ego} (see
+#'        details).
 #' @param set.control.stergm Deprecated control argument of class
 #'        \code{control.stergm}; use \code{set.control.tergm} instead.
 #' @param set.control.tergm Control arguments passed to \code{tergm}
@@ -33,15 +39,15 @@
 #' @param ... Additional arguments passed to other functions.
 #'
 #' @details
-#' \code{netest} is a wrapper function for the \code{ergm} and \code{stergm}
-#' functions that estimate static and dynamic network models, respectively.
-#' Network model estimation is the first step in simulating a stochastic network
-#' epidemic model in \code{EpiModel}. The output from \code{netest} is a
-#' necessary input for running the epidemic simulations in \code{\link{netsim}}.
-#' With a fitted network model, one should always first proceed to model
-#' diagnostics, available through the \code{\link{netdx}} function, to check
-#' model fit. A detailed description of fitting these models, along with
-#' examples, may be found in the
+#' \code{netest} is a wrapper function for the \code{ergm}, \code{ergm.ego},
+#' and \code{tergm} functions that estimate static and dynamic network models.
+#' Network model estimation is the first step in simulating a stochastic
+#' network epidemic model in \code{EpiModel}. The output from \code{netest} is
+#' a necessary input for running the epidemic simulations in
+#' \code{\link{netsim}}. With a fitted network model, one should always first
+#' proceed to model diagnostics, available through the \code{\link{netdx}}
+#' function, to check model fit. A detailed description of fitting these
+#' models, along with examples, may be found in the
 #' \href{http://www.epimodel.org/tut.html}{Basic Network Models} tutorials.
 #'
 #' @section Edges Dissolution Approximation:
@@ -83,8 +89,8 @@
 #' model coefficients (value = \code{TRUE}).
 #'
 #' @section Control Arguments:
-#' The \code{ergm} and \code{tergm} functions allow control settings for the
-#' model fitting process. When fitting a STERGM directly (setting
+#' The \code{ergm}, \code{ergm.ego}, and \code{tergm} functions allow control
+#' settings for the model fitting process. When fitting a STERGM directly (setting
 #' \code{edapprox} to \code{FALSE}), control parameters may be passed to the
 #' \code{tergm} function with the \code{set.control.tergm} argument in
 #' \code{netest}. The controls should be input through the
@@ -93,10 +99,13 @@
 #'
 #' When fitting a STERGM indirectly (setting \code{edapprox} to \code{TRUE}),
 #' control settings may be passed to the \code{ergm} function using
-#' \code{set.control.ergm} in \code{netest}. The controls should be input
-#' through the \code{control.ergm()} function, with the available parameters
-#' listed in the \code{\link[ergm:control.ergm]{control.ergm}} help page in the
-#' \code{ergm} package. An example is below.
+#' \code{set.control.ergm}, or to the \code{ergm.ego} function using
+#' \code{set.control.ergm.ego}.  The controls should be input through the
+#' \code{control.ergm()} and \code{control.ergm.ego()} functions, respectively,
+#' with the available parameters listed in the
+#' \code{\link[ergm:control.ergm]{control.ergm}} help page in the \code{ergm}
+#' package and the \code{\link[ergm.ego:control.ergm.ego]{control.ergm.ego}}
+#' help page in the \code{ergm.ego} package. An example is below.
 #'
 #' @return A fitted network model object of class \code{netest}.
 #'
@@ -146,6 +155,7 @@ netest <- function(nw, formation, target.stats, coef.diss, constraints,
                    set.control.ergm = control.ergm(),
                    set.control.stergm = control.stergm(),
                    set.control.tergm = control.tergm(),
+                   set.control.ergm.ego = control.ergm.ego(),
                    verbose = FALSE, nested.edapprox = TRUE, ...) {
 
   if (!missing(set.control.stergm)) {
@@ -221,16 +231,29 @@ netest <- function(nw, formation, target.stats, coef.diss, constraints,
     out$formula <- fit$formula
 
   } else {
-
     formation.nw <- nonsimp_update.formula(formation, nw ~ ., from.new = "nw")
 
-    fit <- ergm(formation.nw,
-                target.stats = target.stats,
-                constraints = constraints,
-                offset.coef = coef.form,
-                eval.loglik = FALSE,
-                control = set.control.ergm,
-                verbose = verbose)
+    if (is(nw, "egor")) {
+      # ergm.ego case
+      fit <- ergm.ego(formation.nw,
+                      popsize = 0,
+                      constraints = constraints,
+                      offset.coef = coef.form,
+                      control = set.control.ergm.ego,
+                      verbose = verbose)
+
+      target.stats <- fit$m
+
+    } else {
+      # ergm case
+      fit <- ergm(formation.nw,
+                  target.stats = target.stats,
+                  constraints = constraints,
+                  offset.coef = coef.form,
+                  eval.loglik = FALSE,
+                  control = set.control.ergm,
+                  verbose = verbose)
+    }
 
     coef.form <- coef(fit)
     coef.form.crude <- coef.form
@@ -243,8 +266,8 @@ netest <- function(nw, formation, target.stats, coef.diss, constraints,
         ## formation model and appending the relevant values to the vector of
         ## formation model coefficients
         formula_addition <- append_rhs.formula(~., coef.diss$dissolution,
-                                               keep.onesided = TRUE)
-        environment(formula_addition) <- environment(coef.diss$dissolution)
+                                               keep.onesided = TRUE,
+                                               env = environment(coef.diss$dissolution))
 
         # the ... allows for copying via from.new
         formation <- nonsimp_update.formula(formation, formula_addition, ...)
@@ -255,11 +278,8 @@ netest <- function(nw, formation, target.stats, coef.diss, constraints,
     out <- list()
     out$formation <- formation
     out$target.stats <- target.stats
-    if (length(names(coef(fit))) == length(target.stats)) {
-      out$target.stats.names <- names(coef(fit))
-    } else {
-      out$target.stats.names <- names(coef(fit))[!fit$offset]
-    }
+    ## subselect coef names for targeted statistics, including extremal targets
+    out$target.stats.names <- names(coef(fit))[!fit$offset | (fit$drop != 0)]
     out$coef.form <- coef.form
     out$coef.form.crude <- coef.form.crude
     out$coef.diss <- coef.diss
@@ -435,8 +455,8 @@ update_dissolution <- function(old.netest, new.coef.diss,
       formation_list <- formation_list[seq_len(length(formation_list) -
                                                  length(old_diss_list))]
 
-      formation <- append_rhs.formula(~., formation_list)
-      environment(formation) <- environment(out$formation)
+      formation <- append_rhs.formula(~., formation_list,
+                                      env = environment(out$formation))
       formation[[2]] <- NULL # remove the . on the LHS
 
       out$formation <- formation
@@ -463,8 +483,8 @@ update_dissolution <- function(old.netest, new.coef.diss,
       ## formation model and appending the relevant values to the vector of
       ## formation model coefficients
       formula_addition <- append_rhs.formula(~., new.coef.diss$dissolution,
-                                             keep.onesided = TRUE)
-      environment(formula_addition) <- environment(new.coef.diss$dissolution)
+                                             keep.onesided = TRUE,
+                                             env = environment(new.coef.diss$dissolution))
       # the ... allows for copying via from.new
       out$formation <- nonsimp_update.formula(out$formation,
                                               formula_addition, ...)
