@@ -169,7 +169,9 @@ netsim_validate_control <- function(control) {
       "resimulate.network",
       "raw.output",
       "verbose",
-      ".checkpoint.keep"
+      ".checkpoint.keep",
+      ".traceback.on.error",
+      ".dump.frame.on.error"
     )
   )
 
@@ -205,11 +207,14 @@ netsim_initialize <- function(x, param, init, control, s = 1) {
   } else {
     param <- generate_random_params(param, verbose = FALSE)
     dat <- control[["initialize.FUN"]](x, param, init, control, s)
+    dat <- make_module_list(dat)
     if (get_control(dat, "start") != 1) {
       dat <- set_current_timestep(dat, get_control(dat, "start") - 1)
     }
     if (get_control(dat, ".checkpointed"))
       netsim_save_checkpoint(dat, s)
+
+    check_end_horizon_control(dat)
   }
 
   return(dat)
@@ -250,23 +255,13 @@ netsim_run_modules <- function(dat, s) {
       current_mod <- "epimodel.internal"
       # Applies updaters, if any
       dat <- input_updater(dat)
+      dat <- trigger_end_horizon(dat)
 
-      ## Module order
-      morder <- get_control(dat, "module.order", override.null.error = TRUE)
-      if (is.null(morder)) {
-        bi.mods <- get_control(dat, "bi.mods")
-        user.mods <- get_control(dat, "user.mods")
-        lim.bi.mods <- bi.mods[
-          -which(bi.mods %in% c("initialize.FUN", "verbose.FUN"))
-        ]
-        morder <- c(user.mods, lim.bi.mods)
-      }
+      modules <- get_modules(dat)
 
-      ## Evaluate modules
-      for (i in seq_along(morder)) {
-        current_mod <- morder[[i]]
-        mod.FUN <- get_control(dat, current_mod)
-        dat <- do.call(mod.FUN, list(dat, at))
+      for (i in seq_along(modules)) {
+        current_mod <- names(modules)[i]
+        dat <- modules[[i]](dat, at)
       }
 
       current_mod <- "epimodel.internal"
@@ -284,7 +279,10 @@ netsim_run_modules <- function(dat, s) {
     },
     message = function(e) message(netsim_cond_msg("MESSAGE", current_mod, at)),
     warning = function(e) message(netsim_cond_msg("WARNING", current_mod, at)),
-    error = function(e) message(netsim_cond_msg("ERROR", current_mod, at))
+    error = function(e) {
+      message(netsim_cond_msg("ERROR", current_mod, at))
+      netsim_error_logger(dat, s)
+    }
   )
 
   return(dat)
