@@ -1,8 +1,9 @@
-context("Network models with tergmLite")
+context("Network models with tergmLite (All SOC)")
 
 # tergmLite = TRUE -----
 
 test_that("tergmLite: 1G, Closed", {
+  skip_on_cran()
 
   # SI
   num <- 1000
@@ -15,37 +16,44 @@ test_that("tergmLite: 1G, Closed", {
   param <- param.net(inf.prob = 0.1, act.rate = 5)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsteps = 20, nsims = 1, ncores = 1,
-                         resimulate.network = FALSE, tergmLite = TRUE)
+                         resimulate.network = FALSE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = 1)
-  summary(sim, at = 20)
-
+  capture_output(
+    summary(sim, at = 20)
+  )
 
   # SIS
   param <- param.net(inf.prob = 0.5, act.rate = 1, rec.rate = 0.02)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SIS", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = FALSE, tergmLite = TRUE)
+                         resimulate.network = FALSE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = 1)
-  summary(sim, at = 10)
-
+  capture_output(
+    summary(sim, at = 10)
+  )
 
   # SIR
   param <- param.net(inf.prob = 0.5, act.rate = 1, rec.rate = 0.02)
   init <- init.net(i.num = 10, r.num = 5)
   control <- control.net(type = "SIR", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = FALSE, tergmLite = TRUE)
+                         resimulate.network = FALSE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = 1)
-  summary(sim, at = 10)
-
+  capture_output(
+    summary(sim, at = 10)
+  )
 })
 
 test_that("tergmLite: 2G, Closed", {
+  skip_on_cran()
 
   # SI
   num1 <- num2 <- 500
@@ -60,38 +68,48 @@ test_that("tergmLite: 2G, Closed", {
   param <- param.net(inf.prob = 0.4, inf.prob.g2 = 0.2)
   init <- init.net(i.num = 20, i.num.g2 = 20)
   control <- control.net(type = "SI", nsteps = 20, nsims = 1, ncores = 1,
-                         resimulate.network = FALSE, tergmLite = TRUE)
+                         resimulate.network = FALSE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim)
-  summary(sim, at = 20)
+  capture_output(
+    summary(sim, at = 20)
+  )
 
   # SIS
   param <- param.net(inf.prob = 0.4, inf.prob.g2 = 0.2,
                      rec.rate = 0.02, rec.rate.g2 = 0.02)
   init <- init.net(i.num = 20, i.num.g2 = 20)
   control <- control.net(type = "SIS", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = FALSE, tergmLite = TRUE)
+                         resimulate.network = FALSE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim)
-  summary(sim, at = 10)
+  capture_output(
+    summary(sim, at = 10)
+  )
 
   # SIR
   param <- param.net(inf.prob = 0.4, inf.prob.g2 = 0.2,
                      rec.rate = 0.02, rec.rate.g2 = 0.02)
   init <- init.net(i.num = 10, i.num.g2 = 10, r.num = 5, r.num.g2 = 5)
   control <- control.net(type = "SIR", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = FALSE, tergmLite = TRUE)
+                         resimulate.network = FALSE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, mean.col = c(1, 2, 3, 1, 2, 3))
-  summary(sim, at = 10)
+  capture_output(
+    summary(sim, at = 10)
+  )
 
 })
 
 
 test_that("tergmLite: 1G, Open", {
+  skip_on_cran()
 
   # SI
   num <- 1000
@@ -108,24 +126,30 @@ test_that("tergmLite: 1G, Open", {
   init <- init.net(i.num = 10)
   control <- control.net(type = "SI", nsteps = 10, nsims = 1, ncores = 1,
                          resimulate.network = TRUE, tergmLite = TRUE,
-                         verbose = TRUE)
+                         verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = FALSE, sim.lines = TRUE)
   plot(sim, y = "si.flow", ylim = c(0, 20))
-  summary(sim, at = 10)
+  capture_output(
+    summary(sim, at = 10)
+  )
 
   # SIS
   param <- param.net(inf.prob = 0.4, act.rate = 1, rec.rate = 0.02,
                      a.rate = 0.005, ds.rate = 0.005, di.rate = 0.005)
   init <- init.net(i.num = 10)
   control <- control.net(type = "SIS", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = TRUE, tergmLite = TRUE)
+                         resimulate.network = TRUE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = FALSE, sim.lines = TRUE)
   plot(sim, y = c("si.flow", "is.flow"), legend = TRUE)
-  summary(sim, at = 10)
+  capture_output(
+    summary(sim, at = 10)
+  )
 
   # SIR
   param <- param.net(inf.prob = 0.4, act.rate = 1, rec.rate = 0.02,
@@ -133,17 +157,18 @@ test_that("tergmLite: 1G, Open", {
                      dr.rate = 0.005)
   init <- init.net(i.num = 10, r.num = 0)
   control <- control.net(type = "SIR", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = TRUE, tergmLite = TRUE)
+                         resimulate.network = TRUE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = FALSE, sim.lines = TRUE)
   plot(sim, qnts = 1)
   plot(sim, y = "num", ylim = c(800, 1200))
-
 })
 
 
 test_that("tergmLite: 2G, Open", {
+  skip_on_cran()
 
   # SI
   num1 <- num2 <- 500
@@ -162,9 +187,10 @@ test_that("tergmLite: 2G, Open", {
                      di.rate.g2 = 0.005, ds.rate.g2 = 0.005)
   init <- init.net(i.num = 50, i.num.g2 = 50)
   control <- control.net(type = "SI", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = TRUE, tergmLite = TRUE)
+                         resimulate.network = TRUE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = FALSE, sim.lines = TRUE)
   plot(sim, qnts = 1, ylim = c(0, 500))
 
@@ -176,9 +202,10 @@ test_that("tergmLite: 2G, Open", {
                      rec.rate = 0.02, rec.rate.g2 = 0.02)
   init <- init.net(i.num = 50, i.num.g2 = 50)
   control <- control.net(type = "SIS", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = TRUE, tergmLite = TRUE)
+                         resimulate.network = TRUE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = FALSE, sim.lines = TRUE)
   plot(sim, qnts = 1, ylim = c(0, 500))
 
@@ -191,16 +218,17 @@ test_that("tergmLite: 2G, Open", {
                      rec.rate = 0.005, rec.rate.g2 = 0.005)
   init <- init.net(i.num = 10, i.num.g2 = 10, r.num = 5, r.num.g2 = 5)
   control <- control.net(type = "SIR", nsteps = 10, nsims = 1, ncores = 1,
-                         resimulate.network = TRUE, tergmLite = TRUE)
+                         resimulate.network = TRUE, tergmLite = TRUE, verbose = FALSE)
 
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
   plot(sim, qnts = FALSE, sim.lines = TRUE)
   plot(sim, qnts = 1, ylim = c(0, 500))
-
 })
 
 
 test_that("Models with duration = 1", {
+  skip_on_cran()
 
   num <- 1000
   nw <- network_initialize(n = num)
@@ -211,15 +239,16 @@ test_that("Models with duration = 1", {
 
   param <- param.net(inf.prob = 0.1, act.rate = 5)
   init <- init.net(i.num = 10)
-  
-  control <- control.net(type = "SI", nsteps = 5, nsims = 1, ncores = 1,
-                         tergmLite = FALSE, resimulate.network = TRUE)
-  sim <- netsim(est, param, init, control)
 
   control <- control.net(type = "SI", nsteps = 5, nsims = 1, ncores = 1,
-                         tergmLite = TRUE, resimulate.network = TRUE)
+                         tergmLite = FALSE, resimulate.network = TRUE, verbose = FALSE)
   sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
 
+  control <- control.net(type = "SI", nsteps = 5, nsims = 1, ncores = 1,
+                         tergmLite = TRUE, resimulate.network = TRUE, verbose = FALSE)
+  sim <- netsim(est, param, init, control)
+  expect_s3_class(sim, "netsim")
 })
 
 test_that("edgecov works with tergmLite", {
@@ -231,10 +260,11 @@ test_that("edgecov works with tergmLite", {
   ec <- (ec + t(ec))/3
   nw %n% "ec" <- ec
 
-  fit <- netest(nw, 
-                formation = ~edges + nodefactor("race") + edgecov("ec") , 
-                target.stats = c(30, 15, 10), 
-                coef.diss = dissolution_coefs(dissolution = ~offset(edges), duration = 1), edapprox = TRUE)
+  fit <- netest(nw,
+                formation = ~edges + nodefactor("race") + edgecov("ec") ,
+                target.stats = c(30, 15, 10),
+                coef.diss = dissolution_coefs(dissolution = ~offset(edges), duration = 1),
+                edapprox = TRUE)
 
   coefsign <- sign(fit$coef.form.crude[3])
 
@@ -250,8 +280,10 @@ test_that("edgecov works with tergmLite", {
   control <- control.net(type = NULL, nsteps = 4, nsims = 1, ncores = 1,
                          resim_nets.FUN = resim_fun, tergmLite = TRUE,
                          resimulate.network = TRUE, nwstats.formula = ~edges,
-                         set.control.ergm = control.simulate.formula(MCMC.burnin = 1e5))
+                         set.control.ergm = control.simulate.formula(MCMC.burnin = 1e5),
+                         verbose = FALSE)
   sim <- netsim(fit, param, init, control)
+  expect_s3_class(sim, "netsim")
 
   expect_equal(unname(sim$stats$nwstats$sim1[[1]][2,1]), 0)
   expect_equal(unname(sim$stats$nwstats$sim1[[1]][3,1]), network.dyadcount(nw))
