@@ -28,6 +28,15 @@ test_that("Time varying elements", {
       at
     )
 
+    # test when 0 nodes selected
+    some_nodes <- integer(0)
+    dat <- record_attr_history(
+      dat, at,
+      "attr_none",
+      some_nodes,
+      at
+    )
+
     return(dat)
   }
 
@@ -62,5 +71,7 @@ test_that("Time varying elements", {
   attr_history <- get_attr_history(mod)
   expect_is(attr_history, "list")
   expect_is(attr_history[[1]], "data.frame")
-  expect_equal(names(attr_history), c("attr_norm", "attr_unif", "attr_fix"))
+  expect_equal(
+    names(attr_history),
+    c("attr_norm", "attr_unif", "attr_fix", "attr_none"))
 })
